---
title: pymmcore-plus Example
---

# `pymmcore-plus` experiment

This example shows a real-world pattern of streaming to OME-Zarr or OME-TIFF
using [pymmcore-plus](https://pymmcore-plus.github.io/) to interface with a microscope.

```python
--8<-- "examples/pymmcore_plus_example.py"
```
